Linkage disequilibrium
======================

.. automodule:: anhima.ld
.. autofunction:: pairwise_genotype_ld
.. autofunction:: plot_pairwise_ld
.. autofunction:: plot_windowed_ld
.. autofunction:: pairwise_ld_decay
.. autofunction:: windowed_ld_decay
.. autofunction:: plot_ld_decay_by_separation
.. autofunction:: plot_ld_decay_by_distance
.. autofunction:: ld_prune_pairwise

